==> file?get=wackowiki-6.0.38.zip: wackowiki-6.0.38/src/js/lang/wikiedit.en.js <==
lang = {
	// default.js
	ReallySave :			"Really save?",
	ModifiedHint :			"Field has changed, do not forget to save the changes.",
	NotSavedWarning :		"You did not save changes. Are you sure you want to leave?",
	SessionExpiredEditor :	"Your session has expired!\nYou\'ve been logged off due to long inactivity.\n1. Save your form edits to text file to prevent loss.\n2. Refresh the page.\n3. Log in again and re-submit.",

	// wikiedit.js
	HelpAbout :				"Help & About",
	HelpFormatting :		"Help",
	HelpFormattingTip :		"Help on Wiki-formatting",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Heading 1",
	Heading2 :				"Heading 2",
	Heading3 :				"Heading 3",
	Heading4 :				"Heading 4",
	Heading5 :				"Heading 5",
	Heading6 :				"Heading 6",
	Bold :					"Bold",
	Italic :				"Italic",
	Underline :				"Underline",
	Strikethrough :			"Strikethrough",
	Small :					"Small",
	Code :					"Inline code",
	Superscript :			"Superscript",
	Subscript :				"Subscript",
	List :					"List",
	NumberedList :			"Numbered list",
	Left :					"Left",
	Center :				"Center",
	Right :					"Right",
	Justify :				"Justify",
	Outdent :				"Outdent",
	Indent :				"Indent",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Action",
	Line :					"Line",
	Signature :				"Signature",
	Quote :					"Quote",
	MarkedText :			"Marked text",
	HighlightText :			"Highlight text",
	Shade :					"Shade",
	Footnote :				"Footnote",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Insert table",

	Link :					"Link",
	TextForLinking :		"Text for linking",

	HelpAboutTip :			' Shortcuts:\n'+
							' Ctrl+B - Bold\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Underline\n'+
							' Ctrl+Shift+S - Strikethrough\n'+
							' Ctrl+Shift+1 .. 4 - Heading 1..4\n'+
							' Alt+I or Ctrl+T - Indent\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Link with description\n'+
							' Ctrl+Shift+L - Unordered List\n'+
							' Ctrl+Shift+N - Ordered List\n'+
							' Ctrl+Shift+O - Ordered List\n'+
							' Ctrl+= - Small text\n'+
							' Ctrl+Shift+Minus - Horizontal line\n'+
							' \n'
};

==> file?get=wackowiki-6.1.29.zip: wackowiki-6.1.29/src/js/lang/wikiedit.en.js <==
lang = {
	// default.js
	ReallySave :			"Really save?",
	ModifiedHint :			"Field has changed, do not forget to save the changes.",
	NotSavedWarning :		"You did not save changes. Are you sure you want to leave?",
	SessionExpiredEditor :	"Your session has expired!\nYou\'ve been logged off due to long inactivity.\n1. Save your form edits to text file to prevent loss.\n2. Refresh the page.\n3. Log in again and re-submit.",

	// wikiedit.js
	HelpAbout :				"Help & About",
	HelpFormatting :		"Help",
	HelpFormattingTip :		"Help on Wiki formatting",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Heading 1",
	Heading2 :				"Heading 2",
	Heading3 :				"Heading 3",
	Heading4 :				"Heading 4",
	Heading5 :				"Heading 5",
	Heading6 :				"Heading 6",
	Bold :					"Bold",
	Italic :				"Italic",
	Underline :				"Underline",
	Strikethrough :			"Strikethrough",
	Small :					"Small",
	Code :					"Inline code",
	Superscript :			"Superscript",
	Subscript :				"Subscript",
	List :					"List",
	NumberedList :			"Numbered list",
	Left :					"Left",
	Center :				"Center",
	Right :					"Right",
	Justify :				"Justify",
	Outdent :				"Outdent",
	Indent :				"Indent",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Action",
	Line :					"Line",
	Signature :				"Signature",
	Quote :					"Quote",
	MarkedText :			"Marked text",
	HighlightText :			"Highlight text",
	Shade :					"Shade",
	Footnote :				"Footnote",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Insert table",

	Link :					"Link",
	TextForLinking :		"Text for linking",

	HelpAboutTip :			' Shortcuts:\n'+
							' Ctrl+B - Bold\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Underline\n'+
							' Ctrl+Shift+S - Strikethrough\n'+
							' Ctrl+Shift+1 .. 4 - Heading 1..4\n'+
							' Alt+I or Ctrl+T - Indent\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Link with description\n'+
							' Ctrl+Shift+L - Unordered List\n'+
							' Ctrl+Shift+N - Ordered List\n'+
							' Ctrl+Shift+O - Ordered List\n'+
							' Ctrl+= - Small text\n'+
							' Ctrl+Shift+Minus - Horizontal line\n'+
							' \n'
};
